#
# spec file for package bumblebee
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bumblebee
Version:        3.2.1
Release:        14.21
Summary:        NVidia Optimus support for GNU/Linux aimed at stability
License:        GPL-3.0-or-later
Group:          Hardware/Other
URL:            https://github.com/Bumblebee-Project/bumblebee
Source0:        http://bumblebee-project.org/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Patch0:         nvidia-uvm-modeset-drm-support.patch
Patch1:         bumblebee-decimal-pciid.patch
# PATCH-FIX-UPSTREAM
Patch2:         Fix_build_with_GCC10.patch
BuildRequires:  glib2-devel
BuildRequires:  help2man
BuildRequires:  pciutils
BuildRequires:  pkgconfig
BuildRequires:  pwdutils
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  pkgconfig(systemd)
Requires:       VirtualGL
Requires:       pciutils
Requires:       primus
Requires:       shadow
Requires:       sudo
Requires:       xorg-x11-libX11
Recommends:     bbswitch
%{?systemd_requires}
# Always want 32b version on 64b system
%ifarch x86_64
Recommends:     VirtualGL-32bit
%endif
# Always want 32b version on 64b system
%ifarch x86_64
Recommends:     primus-32bit
%endif
%if 0%{?suse_version} < 1315
Requires:       module-init-tools
%else
Requires:       kmod-compat
%endif

%description
The Bumblebee daemon is a rewrite of the original Bumblebee service,
providing a means of managing Optimus hybrid graphics chipsets. This
project not only enables use of the discrete GPU for rendering, but
also smart power management of the dGPU when it is not in use.

%prep
%autosetup -p1

%build
%configure \
	--without-pidfile \
	--with-udev-rules=%{_udevrulesdir}/ \
	CONF_DRIVER_MODULE_NVIDIA=nvidia CONF_LDPATH_NVIDIA=%{_libdir}/nvidia:%{_prefix}/lib/nvidia \
	CONF_MODPATH_NVIDIA=%{_libdir}/nvidia/xorg/,%{_libdir}/xorg/modules \
	CONF_PRIMUS_LD_PATH=%{_libdir}/primus:%{_prefix}/lib/primus

make %{?_smp_mflags}

%install
%make_install
install -d 755 %{buildroot}%{_prefix}/lib/systemd
install -D -m644 "%{_builddir}/%{name}-%{version}/scripts/systemd/bumblebeed.service" "%{buildroot}%{_unitdir}/bumblebeed.service"
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcbumblebeed
# Fix service to run after dkms and modules leading service
sed -i '3i After=dkms.service systemd-modules-load.service' %{buildroot}%{_unitdir}/bumblebeed.service
# according to rpmlint error suse-filelist-forbidden-bashcomp-userdirs
install -d -m 0755 %{buildroot}/%{_datadir}/bash-completion/completions/
mv %{buildroot}/%{_sysconfdir}/bash_completion.d/bumblebee %{buildroot}/%{_datadir}/bash-completion/completions/

%pre
getent group bumblebee >/dev/null || groupadd -r bumblebee
%service_add_pre bumblebeed.service

%post
%udev_rules_update
%service_add_post bumblebeed.service
# Notify user about the groups
mkdir -p %{_localstatedir}/adm/update-messages
cat > %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}-something << EOF
INFO: Please ensure that users using bublebee/video card are in following group(s):
INFO:     gpasswd -a <USER> bumblebee
INFO:   If going to use nvidia binary driver:
INFO:     gpasswd -a <USER> video
INFO: Also ensure the nouveau module is blacklisted (even if you plan to use it):
INFO:     echo "blacklist nouveau" >> %{_sysconfdir}/modprobe.d/50-blacklist.conf
INFO:     mkinitrd
EOF

%preun
%service_del_preun bumblebeed.service

%postun
%service_del_postun bumblebeed.service

%files
%license COPYING
%doc README.markdown
%dir %{_sysconfdir}/bumblebee
%config(noreplace) %{_sysconfdir}/bumblebee/xorg.conf.nouveau
%config(noreplace) %{_sysconfdir}/bumblebee/xorg.conf.nvidia
%config(noreplace) %{_sysconfdir}/bumblebee/bumblebee.conf
%dir %{_sysconfdir}/bumblebee/xorg.conf.d
%config %{_sysconfdir}/bumblebee/xorg.conf.d/10-dummy.conf
%{_unitdir}/bumblebeed.service
%{_sbindir}/rcbumblebeed
%{_udevrulesdir}/99-bumblebee-nvidia-dev.rules
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/bumblebee
%{_datadir}/doc/bumblebee
%{_sbindir}/bumblebeed
%{_bindir}/optirun
%{_bindir}/bumblebee-bugreport
%{_mandir}/man1/bumblebeed.1%{?ext_man}
%{_mandir}/man1/optirun.1%{?ext_man}

%changelog
* Mon Sep 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add Debian patch to fix build with GCC10:
  * Fix_build_with_GCC10.patch
* Wed Aug 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
- Drop pwdutils Requires: pwdutils has been provided by shadow,
  which is also required, for a long time.
* Tue Aug  7 2018 tchvatal@suse.com
- Fix directory mode on the bash-completion
* Sat Jul 28 2018 jengelh@inai.de
- Trim aims from description, say what it does. Trim bias.
- Do not ignore errors from groupadd.
* Fri Jul 27 2018 sven@uebelacker.net
- Please, do not overwrite bumblebee configs (adding noreplace)
- fixing some rpmlint errors
  * bash-completion goes to /usr/share/bash-completion/completions/ not /etc/bash_completion.d/
  * rpmlint filter for zero-size 10-dummy.conf
* Wed Jul 25 2018 tchvatal@suse.com
- Run %%udev_rules_update in post
* Thu Aug 10 2017 olaf@aepfle.de
- Update filename in /var/adm/update-messages to match documentation,
  and build-compare pattern
* Sat Nov 19 2016 tchvatal@suse.com
- Update dirs handling to work correctly on Backports project
* Wed Aug 24 2016 tchvatal@suse.com
- Add patch for bnc#994454 pciid's bigger than 9:
  * bumblebee-decimal-pciid.patch
* Sun Aug  7 2016 bumblebee.obs@gmail.com
- Update patch to add/remove /dev/nvidia-uvm for CUDA and remove
  /dev/nvdia-modeset on demand :
  * nvidia-uvm-modeset-drm-support.patch
* Mon Apr 11 2016 bumblebee.obs@gmail.com
- Update patch to correctly load/unload nvidia-modeset and
  nvidia-drm:
  * Extended and renamed nvidia-uvm-support.patch
    to nvidia-uvm-modeset-drm-support.patch
* Wed Jan 21 2015 arnaldo.coelho@gmail.com
- Added patch to correctly load/unload nvidia-uvm:
  * nvidia-uvm-support.patch
* Tue Nov 11 2014 tchvatal@suse.com
- Only recommend 32b stuff.
* Wed Jun 25 2014 tchvatal@suse.com
- Install README and COPYING
* Fri Jun 13 2014 tchvatal@suse.com
- Require systemd-modules-load.service to be present for our service
* Wed Jun  4 2014 tchvatal@suse.com
- Add mention aboud the blacklist requirement for nouveau.
* Wed Jun  4 2014 tchvatal@suse.com
- Recommend bbswitch to install the default module, which should
  now be autoloaded.
* Thu Feb 20 2014 tchvatal@suse.com
- Require primus and primus-32bit. Fix typo in previous commit.
* Thu Feb 20 2014 tchvatal@suse.com
- Always require 32b version of virtualgl on 64b system
* Thu Feb 20 2014 tchvatal@suse.com
- Remove some redundant dependencies
- Provide rcbumblebeed symlink for service control.
* Fri Feb  7 2014 tchvatal@suse.com
- Use 1315 as version string as kmod is also in SLE12.
* Sun Jan 26 2014 tchvatal@suse.com
- Update my clumsy wording on postinst info.
* Mon Jan 20 2014 tchvatal@suse.com
- Notify user about the group actions, do not create and delete
  it automatically. It can cause more problems than the benefits
  are from it.
* Fri Jan 17 2014 tchvatal@suse.com
- Sort out the dep on kmod-compat or module-init-tools
* Tue Jan 14 2014 tchvatal@suse.com
- Use suse macros to build and sort out BuildRequires to contain
  needed stuff.
* Tue Jan 14 2014 tchvatal@suse.com
- Format the spec-file up to openSUSE requirements.
* Tue Jan 14 2014 tchvatal@suse.com
- Covert to use proper changelog file.
